@@ -29,18 +29,28 @@ import org.biolegato.core.main.BLMain;
  */
 public class PluginLoader {
 
+    
     /**
      * Stores all of the plugins lodaed by BioLegato.<br />
      * NOTE: plugins are only loaded once at the start of the program.
      */
-    private static Hashtable<String, PluginWrapper> plugins = new Hashtable<String, PluginWrapper>();
+    private Hashtable<String, PluginWrapper> plugins = new Hashtable<String, PluginWrapper>();
 
+    /**
+     * Loads an the plugins into BioLegato.
+     **
+     * @param directory the directory to load the plugins from
+     */
+    public PluginLoader(String directory) {
+        loadPlugins(directory);
+    }
+    
     /**
      * Maintains a list with all of the plugins loaded by BioLegato.
      *
      * @return a list containing all of the plugins loaded
      */
-    public static Map<String, PluginWrapper> getPluginHash() {
+    public Map<String, PluginWrapper> getPluginHash() {
         return new Hashtable<String, PluginWrapper>(plugins);
     }
 
@@ -51,7 +61,7 @@ public class PluginLoader {
      * @param type the plugin type to find
      * @return a list containing all of the plugins loaded
      */
-    public static Collection<PluginWrapper> getPlugins(Class<?> type) {
+    public Collection<PluginWrapper> getPlugins(Class<?> type) {
         ArrayList<PluginWrapper> list = new ArrayList<PluginWrapper>();   // the list of plugins to return
 
         // itterate through the plugins and extract those which are instances ot "type"
@@ -70,16 +80,16 @@ public class PluginLoader {
      * @param string the plugin to retrieve
      * @return the plugin requested (null on failure)
      */
-    public static PluginWrapper getPlugin(String string) {
+    public PluginWrapper getPlugin(String string) {
         return plugins.get(string);
     }
 
     /**
      * Loads an the plugins into BioLegato.
-     *
+     **
      * @param directory the directory to load the plugins from
      */
-    public static void loadPlugins(String directory) {
+    private void loadPlugins(String directory) {
         String className = "";			    // the name of the current class
         File pluginDirectory = new File(directory); // the current directory to load from
 
@@ -112,7 +122,7 @@ public class PluginLoader {
      * 
      * @param file the jar file to read classes from.
      */
-    private static void loadJar(File file) throws IOException {
+    private void loadJar(File file) throws IOException {
         Enumeration<JarEntry> entries = null;	    // the current list of entries in the jar file
         JarFile jarfile = new JarFile(file);	    // the jar file object to read
         JarEntry entry = null;			    // the current entry being parsed
@@ -137,7 +147,7 @@ public class PluginLoader {
      * @param name the name of the class to load
      * @param file the file that contains the classes
      */
-    private static void loadClass(URL url, String name) {
+    private void loadClass(URL url, String name) {
         try {
             // load the class
             Class currentClass = new URLClassLoader(new URL[]{url}).loadClass(name);
