@@ -5,7 +5,7 @@
 
 package org.biolegato.gdesupport.canvas.listeners;
 
-import org.biolegato.gdesupport.canvas.BLTextArea;
+import org.biolegato.gdesupport.canvas.textarea.BLTextArea;
 
 /**
  * Used to communicate changes in the canvas cursor position.
